slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPGetConvergenceTest

Gets the method used to compute the error estimate used in the convergence test.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPGetConvergenceTest(NEP nep,NEPConv *conv)

Not Collective

### Input Parameters

| nep | - nonlinear eigensolver context obtained from NEPCreate()

### Output Parameters

| conv | - the type of convergence test

### See Also

NEPSetConvergenceTest(), NEPConv

### Level

intermediate

### Location

src/nep/interface/nepopts.c
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages